@@ -27,6 +27,7 @@ from .literals import (
     RepositoryProviderType,
     ResourceDeploymentStatusType,
     SortOrderType,
+    SyncTypeType,
     TemplateTypeType,
     TemplateVersionStatusType,
 )
@@ -65,7 +66,9 @@ from .type_defs import (
     CreateEnvironmentTemplateOutputTypeDef,
     CreateEnvironmentTemplateVersionOutputTypeDef,
     CreateRepositoryOutputTypeDef,
+    CreateServiceInstanceOutputTypeDef,
     CreateServiceOutputTypeDef,
+    CreateServiceSyncConfigOutputTypeDef,
     CreateServiceTemplateOutputTypeDef,
     CreateServiceTemplateVersionOutputTypeDef,
     CreateTemplateSyncConfigOutputTypeDef,
@@ -76,6 +79,7 @@ from .type_defs import (
     DeleteEnvironmentTemplateVersionOutputTypeDef,
     DeleteRepositoryOutputTypeDef,
     DeleteServiceOutputTypeDef,
+    DeleteServiceSyncConfigOutputTypeDef,
     DeleteServiceTemplateOutputTypeDef,
     DeleteServiceTemplateVersionOutputTypeDef,
     DeleteTemplateSyncConfigOutputTypeDef,
@@ -90,7 +94,10 @@ from .type_defs import (
     GetRepositorySyncStatusOutputTypeDef,
     GetResourcesSummaryOutputTypeDef,
     GetServiceInstanceOutputTypeDef,
+    GetServiceInstanceSyncStatusOutputTypeDef,
     GetServiceOutputTypeDef,
+    GetServiceSyncBlockerSummaryOutputTypeDef,
+    GetServiceSyncConfigOutputTypeDef,
     GetServiceTemplateOutputTypeDef,
     GetServiceTemplateVersionOutputTypeDef,
     GetTemplateSyncConfigOutputTypeDef,
@@ -130,6 +137,8 @@ from .type_defs import (
     UpdateServiceInstanceOutputTypeDef,
     UpdateServiceOutputTypeDef,
     UpdateServicePipelineOutputTypeDef,
+    UpdateServiceSyncBlockerOutputTypeDef,
+    UpdateServiceSyncConfigOutputTypeDef,
     UpdateServiceTemplateOutputTypeDef,
     UpdateServiceTemplateVersionOutputTypeDef,
     UpdateTemplateSyncConfigOutputTypeDef,
@@ -268,6 +277,7 @@ class ProtonClient(BaseClient):
         manifest: str,
         name: str,
         templateFile: str,
+        clientToken: str = ...,
         description: str = ...,
         environmentName: str = ...,
         serviceInstanceName: str = ...,
@@ -396,6 +406,40 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#create_service)
         """
 
+    def create_service_instance(
+        self,
+        *,
+        name: str,
+        serviceName: str,
+        spec: str,
+        clientToken: str = ...,
+        tags: Sequence[TagTypeDef] = ...,
+        templateMajorVersion: str = ...,
+        templateMinorVersion: str = ...
+    ) -> CreateServiceInstanceOutputTypeDef:
+        """
+        Create a service instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.create_service_instance)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#create_service_instance)
+        """
+
+    def create_service_sync_config(
+        self,
+        *,
+        branch: str,
+        filePath: str,
+        repositoryName: str,
+        repositoryProvider: RepositoryProviderType,
+        serviceName: str
+    ) -> CreateServiceSyncConfigOutputTypeDef:
+        """
+        Create the Proton Ops configuration file.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.create_service_sync_config)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#create_service_sync_config)
+        """
+
     def create_service_template(
         self,
         *,
@@ -514,6 +558,16 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#delete_service)
         """
 
+    def delete_service_sync_config(
+        self, *, serviceName: str
+    ) -> DeleteServiceSyncConfigOutputTypeDef:
+        """
+        Delete the Proton Ops file.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.delete_service_sync_config)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#delete_service_sync_config)
+        """
+
     def delete_service_template(self, *, name: str) -> DeleteServiceTemplateOutputTypeDef:
         """
         If no other major or minor versions of the service template exist, delete the
@@ -627,7 +681,7 @@ class ProtonClient(BaseClient):
         branch: str,
         repositoryName: str,
         repositoryProvider: RepositoryProviderType,
-        syncType: Literal["TEMPLATE_SYNC"]
+        syncType: SyncTypeType
     ) -> GetRepositorySyncStatusOutputTypeDef:
         """
         Get the sync status of a repository used for Proton template sync.
@@ -662,6 +716,34 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service_instance)
         """
 
+    def get_service_instance_sync_status(
+        self, *, serviceInstanceName: str, serviceName: str
+    ) -> GetServiceInstanceSyncStatusOutputTypeDef:
+        """
+        Get the status of the synced service instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_service_instance_sync_status)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service_instance_sync_status)
+        """
+
+    def get_service_sync_blocker_summary(
+        self, *, serviceName: str, serviceInstanceName: str = ...
+    ) -> GetServiceSyncBlockerSummaryOutputTypeDef:
+        """
+        Get detailed data for the service sync blocker summary.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_service_sync_blocker_summary)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service_sync_blocker_summary)
+        """
+
+    def get_service_sync_config(self, *, serviceName: str) -> GetServiceSyncConfigOutputTypeDef:
+        """
+        Get detailed information for the service sync configuration.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.get_service_sync_config)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#get_service_sync_config)
+        """
+
     def get_service_template(self, *, name: str) -> GetServiceTemplateOutputTypeDef:
         """
         Get detailed data for a service template.
@@ -826,7 +908,7 @@ class ProtonClient(BaseClient):
         *,
         repositoryName: str,
         repositoryProvider: RepositoryProviderType,
-        syncType: Literal["TEMPLATE_SYNC"],
+        syncType: SyncTypeType,
         nextToken: str = ...
     ) -> ListRepositorySyncDefinitionsOutputTypeDef:
         """
@@ -1003,6 +1085,7 @@ class ProtonClient(BaseClient):
         *,
         deploymentType: ComponentDeploymentUpdateTypeType,
         name: str,
+        clientToken: str = ...,
         description: str = ...,
         serviceInstanceName: str = ...,
         serviceName: str = ...,
@@ -1096,6 +1179,7 @@ class ProtonClient(BaseClient):
         deploymentType: DeploymentUpdateTypeType,
         name: str,
         serviceName: str,
+        clientToken: str = ...,
         spec: str = ...,
         templateMajorVersion: str = ...,
         templateMinorVersion: str = ...
@@ -1123,6 +1207,32 @@ class ProtonClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_service_pipeline)
         """
 
+    def update_service_sync_blocker(
+        self, *, id: str, resolvedReason: str
+    ) -> UpdateServiceSyncBlockerOutputTypeDef:
+        """
+        Update the service sync blocker by resolving it.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.update_service_sync_blocker)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_service_sync_blocker)
+        """
+
+    def update_service_sync_config(
+        self,
+        *,
+        branch: str,
+        filePath: str,
+        repositoryName: str,
+        repositoryProvider: RepositoryProviderType,
+        serviceName: str
+    ) -> UpdateServiceSyncConfigOutputTypeDef:
+        """
+        Update the Proton Ops config file.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Client.update_service_sync_config)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton/client/#update_service_sync_config)
+        """
+
     def update_service_template(
         self, *, name: str, description: str = ..., displayName: str = ...
     ) -> UpdateServiceTemplateOutputTypeDef:
