@@ -6,9 +6,9 @@ Type annotations for proton service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_proton.literals import ComponentDeletedWaiterName
+    from mypy_boto3_proton.literals import BlockerStatusType
 
-    data: ComponentDeletedWaiterName = "component_deleted"
+    data: BlockerStatusType = "ACTIVE"
     ```
 """
 import sys
@@ -20,6 +20,8 @@ else:
 
 
 __all__ = (
+    "BlockerStatusType",
+    "BlockerTypeType",
     "ComponentDeletedWaiterName",
     "ComponentDeployedWaiterName",
     "ComponentDeploymentUpdateTypeType",
@@ -78,6 +80,8 @@ __all__ = (
 )
 
 
+BlockerStatusType = Literal["ACTIVE", "RESOLVED"]
+BlockerTypeType = Literal["AUTOMATED"]
 ComponentDeletedWaiterName = Literal["component_deleted"]
 ComponentDeployedWaiterName = Literal["component_deployed"]
 ComponentDeploymentUpdateTypeType = Literal["CURRENT_VERSION", "NONE"]
@@ -173,7 +177,7 @@ ServiceTemplateSupportedComponentSourceTypeType = Literal["DIRECTLY_DEFINED"]
 ServiceTemplateVersionRegisteredWaiterName = Literal["service_template_version_registered"]
 ServiceUpdatedWaiterName = Literal["service_updated"]
 SortOrderType = Literal["ASCENDING", "DESCENDING"]
-SyncTypeType = Literal["TEMPLATE_SYNC"]
+SyncTypeType = Literal["SERVICE_SYNC", "TEMPLATE_SYNC"]
 TemplateTypeType = Literal["ENVIRONMENT", "SERVICE"]
 TemplateVersionStatusType = Literal[
     "DRAFT", "PUBLISHED", "REGISTRATION_FAILED", "REGISTRATION_IN_PROGRESS"
@@ -327,6 +331,7 @@ ServiceName = Literal[
     "importexport",
     "inspector",
     "inspector2",
+    "internetmonitor",
     "iot",
     "iot-data",
     "iot-jobs-data",
@@ -345,6 +350,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivs-realtime",
     "ivschat",
     "kafka",
     "kafkaconnect",
@@ -503,10 +509,12 @@ ServiceName = Literal[
     "textract",
     "timestream-query",
     "timestream-write",
+    "tnb",
     "transcribe",
     "transfer",
     "translate",
     "voice-id",
+    "vpc-lattice",
     "waf",
     "waf-regional",
     "wafv2",
