@@ -57,7 +57,6 @@ Usage::
     list_tags_for_resource_paginator: ListTagsForResourcePaginator = client.get_paginator("list_tags_for_resource")
     ```
 """
-import sys
 from typing import Generic, Iterator, Sequence, TypeVar
 
 from botocore.paginate import PageIterator, Paginator
@@ -68,6 +67,7 @@ from .literals import (
     ListServiceInstancesSortByType,
     RepositoryProviderType,
     SortOrderType,
+    SyncTypeType,
 )
 from .type_defs import (
     EnvironmentTemplateFilterTypeDef,
@@ -95,12 +95,6 @@ from .type_defs import (
     PaginatorConfigTypeDef,
 )
 
-if sys.version_info >= (3, 9):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = (
     "ListComponentOutputsPaginator",
     "ListComponentProvisionedResourcesPaginator",
@@ -313,7 +307,7 @@ class ListRepositorySyncDefinitionsPaginator(Paginator):
         *,
         repositoryName: str,
         repositoryProvider: RepositoryProviderType,
-        syncType: Literal["TEMPLATE_SYNC"],
+        syncType: SyncTypeType,
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRepositorySyncDefinitionsOutputTypeDef]:
         """
